package com.ruoyi.common.pay.yst.domain;


import com.alibaba.fastjson2.JSONObject;

import java.util.List;
import java.util.Map;

/**
 * 业务参数
 *
 * @author gejunqing
 * @version 1.0
 * @date 2024/1/11
 */
public class BizParameter extends JSONObject
{
    public void addParam(String paramName, String paramValue)
    {
        this.put(paramName, paramValue);
    }

    public void addParam(String paramName, int paramValue)
    {
        this.put(paramName, paramValue);
    }

    public void addMapParam(String paramName, Map<String, Object> paramMap)
    {
        this.put(paramName, paramMap);
    }
    public void addListParam(String paramName, List paramValue)
    {
        this.put(paramName, paramValue);
    }

    public void addParamNoNull(String paramName, Object paramValue) {
        if (paramValue != null) {
            this.put(paramName, paramValue);
        }
    }
}
